/****************************************************************************
** Meta object code from reading C++ file 'dbusextendedabstractinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "dbusextendedabstractinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dbusextendedabstractinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29DBusExtendedAbstractInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto DBusExtendedAbstractInterface::qt_create_metaobjectdata<qt_meta_tag_ZN29DBusExtendedAbstractInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DBusExtendedAbstractInterface",
        "propertyChanged",
        "",
        "propertyName",
        "QVariant",
        "value",
        "propertyInvalidated",
        "asyncPropertyFinished",
        "asyncSetPropertyFinished",
        "asyncGetAllPropertiesFinished",
        "onPropertiesChanged",
        "interfaceName",
        "QVariantMap",
        "changedProperties",
        "invalidatedProperties",
        "onAsyncPropertyFinished",
        "DBusExtendedPendingCallWatcher*",
        "watcher",
        "onAsyncSetPropertyFinished",
        "onAsyncGetAllPropertiesFinished",
        "QDBusPendingCallWatcher*",
        "sync",
        "useCache"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'propertyChanged'
        QtMocHelpers::SignalData<void(const QString &, const QVariant &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'propertyInvalidated'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'asyncPropertyFinished'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'asyncSetPropertyFinished'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'asyncGetAllPropertiesFinished'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onPropertiesChanged'
        QtMocHelpers::SlotData<void(const QString &, const QVariantMap &, const QStringList &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { 0x80000000 | 12, 13 }, { QMetaType::QStringList, 14 },
        }}),
        // Slot 'onAsyncPropertyFinished'
        QtMocHelpers::SlotData<void(DBusExtendedPendingCallWatcher *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'onAsyncSetPropertyFinished'
        QtMocHelpers::SlotData<void(DBusExtendedPendingCallWatcher *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'onAsyncGetAllPropertiesFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sync'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'useCache'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DBusExtendedAbstractInterface, qt_meta_tag_ZN29DBusExtendedAbstractInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject DBusExtendedAbstractInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29DBusExtendedAbstractInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29DBusExtendedAbstractInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29DBusExtendedAbstractInterfaceE_t>.metaTypes,
    nullptr
} };

void DBusExtendedAbstractInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DBusExtendedAbstractInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->propertyChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 1: _t->propertyInvalidated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->asyncPropertyFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->asyncSetPropertyFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->asyncGetAllPropertiesFinished(); break;
        case 5: _t->onPropertiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 6: _t->onAsyncPropertyFinished((*reinterpret_cast<std::add_pointer_t<DBusExtendedPendingCallWatcher*>>(_a[1]))); break;
        case 7: _t->onAsyncSetPropertyFinished((*reinterpret_cast<std::add_pointer_t<DBusExtendedPendingCallWatcher*>>(_a[1]))); break;
        case 8: _t->onAsyncGetAllPropertiesFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DBusExtendedAbstractInterface::*)(const QString & , const QVariant & )>(_a, &DBusExtendedAbstractInterface::propertyChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusExtendedAbstractInterface::*)(const QString & )>(_a, &DBusExtendedAbstractInterface::propertyInvalidated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusExtendedAbstractInterface::*)(const QString & )>(_a, &DBusExtendedAbstractInterface::asyncPropertyFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusExtendedAbstractInterface::*)(const QString & )>(_a, &DBusExtendedAbstractInterface::asyncSetPropertyFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DBusExtendedAbstractInterface::*)()>(_a, &DBusExtendedAbstractInterface::asyncGetAllPropertiesFinished, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->sync(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->useCache(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSync(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setUseCache(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DBusExtendedAbstractInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DBusExtendedAbstractInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29DBusExtendedAbstractInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int DBusExtendedAbstractInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void DBusExtendedAbstractInterface::propertyChanged(const QString & _t1, const QVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void DBusExtendedAbstractInterface::propertyInvalidated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DBusExtendedAbstractInterface::asyncPropertyFinished(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DBusExtendedAbstractInterface::asyncSetPropertyFinished(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DBusExtendedAbstractInterface::asyncGetAllPropertiesFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
