/****************************************************************************
** Meta object code from reading C++ file 'mpris.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "mpris.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mpris.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5MprisE_t {};
} // unnamed namespace

template <> constexpr inline auto Mpris::qt_create_metaobjectdata<qt_meta_tag_ZN5MprisE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Mpris",
        "metadataToString",
        "",
        "Metadata",
        "metadata",
        "PlaybackStatus",
        "InvalidPlaybackStatus",
        "Playing",
        "Paused",
        "Stopped",
        "LoopStatus",
        "InvalidLoopStatus",
        "None",
        "Track",
        "Playlist",
        "InvalidMetadata",
        "TrackId",
        "Length",
        "ArtUrl",
        "Album",
        "AlbumArtist",
        "Artist",
        "AsText",
        "AudioBPM",
        "AutoRating",
        "Comment",
        "Composer",
        "ContentCreated",
        "DiscNumber",
        "FirstUsed",
        "Genre",
        "LastUsed",
        "Lyricist",
        "Title",
        "TrackNumber",
        "Url",
        "UseCount",
        "UserRating"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'metadataToString'
        QtMocHelpers::MethodData<QString(enum Metadata)>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'PlaybackStatus'
        QtMocHelpers::EnumData<enum PlaybackStatus>(5, 5, QMC::EnumFlags{}).add({
            {    6, PlaybackStatus::InvalidPlaybackStatus },
            {    7, PlaybackStatus::Playing },
            {    8, PlaybackStatus::Paused },
            {    9, PlaybackStatus::Stopped },
        }),
        // enum 'LoopStatus'
        QtMocHelpers::EnumData<enum LoopStatus>(10, 10, QMC::EnumFlags{}).add({
            {   11, LoopStatus::InvalidLoopStatus },
            {   12, LoopStatus::None },
            {   13, LoopStatus::Track },
            {   14, LoopStatus::Playlist },
        }),
        // enum 'Metadata'
        QtMocHelpers::EnumData<enum Metadata>(3, 3, QMC::EnumFlags{}).add({
            {   15, Metadata::InvalidMetadata },
            {   16, Metadata::TrackId },
            {   17, Metadata::Length },
            {   18, Metadata::ArtUrl },
            {   19, Metadata::Album },
            {   20, Metadata::AlbumArtist },
            {   21, Metadata::Artist },
            {   22, Metadata::AsText },
            {   23, Metadata::AudioBPM },
            {   24, Metadata::AutoRating },
            {   25, Metadata::Comment },
            {   26, Metadata::Composer },
            {   27, Metadata::ContentCreated },
            {   28, Metadata::DiscNumber },
            {   29, Metadata::FirstUsed },
            {   30, Metadata::Genre },
            {   31, Metadata::LastUsed },
            {   32, Metadata::Lyricist },
            {   33, Metadata::Title },
            {   34, Metadata::TrackNumber },
            {   35, Metadata::Url },
            {   36, Metadata::UseCount },
            {   37, Metadata::UserRating },
        }),
    };
    return QtMocHelpers::metaObjectData<Mpris, qt_meta_tag_ZN5MprisE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Mpris::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5MprisE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5MprisE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5MprisE_t>.metaTypes,
    nullptr
} };

void Mpris::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Mpris *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->metadataToString((*reinterpret_cast<std::add_pointer_t<enum Metadata>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *Mpris::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Mpris::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5MprisE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Mpris::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
