/****************************************************************************
** Meta object code from reading C++ file 'mprisplayer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "mprisplayer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mprisplayer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11MprisPlayerE_t {};
} // unnamed namespace

template <> constexpr inline auto MprisPlayer::qt_create_metaobjectdata<qt_meta_tag_ZN11MprisPlayerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MprisPlayer",
        "serviceNameChanged",
        "",
        "canQuitChanged",
        "canRaiseChanged",
        "canSetFullscreenChanged",
        "desktopEntryChanged",
        "fullscreenChanged",
        "hasTrackListChanged",
        "identityChanged",
        "supportedUriSchemesChanged",
        "supportedMimeTypesChanged",
        "fullscreenRequested",
        "fullscreen",
        "quitRequested",
        "raiseRequested",
        "canControlChanged",
        "canShowInUIChanged",
        "canGoNextChanged",
        "canGoPreviousChanged",
        "canPauseChanged",
        "canPlayChanged",
        "canSeekChanged",
        "loopStatusChanged",
        "maximumRateChanged",
        "metadataChanged",
        "minimumRateChanged",
        "playbackStatusChanged",
        "positionChanged",
        "rateChanged",
        "shuffleChanged",
        "volumeChanged",
        "loopStatusRequested",
        "Mpris::LoopStatus",
        "loopStatus",
        "rateRequested",
        "rate",
        "shuffleRequested",
        "shuffle",
        "volumeRequested",
        "volume",
        "nextRequested",
        "openUriRequested",
        "QUrl",
        "url",
        "pauseRequested",
        "playRequested",
        "playPauseRequested",
        "previousRequested",
        "seekRequested",
        "offset",
        "seeked",
        "position",
        "setPositionRequested",
        "QDBusObjectPath",
        "trackId",
        "stopRequested",
        "serviceName",
        "setServiceName",
        "canQuit",
        "setCanQuit",
        "canRaise",
        "setCanRaise",
        "canSetFullscreen",
        "setCanSetFullscreen",
        "desktopEntry",
        "setDesktopEntry",
        "setFullscreen",
        "hasTrackList",
        "setHasTrackList",
        "identity",
        "setIdentity",
        "supportedUriSchemes",
        "setSupportedUriSchemes",
        "supportedMimeTypes",
        "setSupportedMimeTypes",
        "canControl",
        "setCanControl",
        "canShowInUI",
        "setCanShowInUI",
        "canGoNext",
        "setCanGoNext",
        "canGoPrevious",
        "setCanGoPrevious",
        "canPause",
        "setCanPause",
        "canPlay",
        "setCanPlay",
        "canSeek",
        "setCanSeek",
        "setLoopStatus",
        "maximumRate",
        "setMaximumRate",
        "metadata",
        "QVariantMap",
        "setMetadata",
        "minimumRate",
        "setMinimumRate",
        "playbackStatus",
        "Mpris::PlaybackStatus",
        "setPlaybackStatus",
        "setPosition",
        "setRate",
        "setShuffle",
        "setVolume"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'serviceNameChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canQuitChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canRaiseChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSetFullscreenChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desktopEntryChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullscreenChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hasTrackListChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportedUriSchemesChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'supportedMimeTypesChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullscreenRequested'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'quitRequested'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'raiseRequested'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canControlChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canShowInUIChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canGoNextChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canGoPreviousChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPauseChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canPlayChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canSeekChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loopStatusChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximumRateChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'metadataChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimumRateChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playbackStatusChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rateChanged'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shuffleChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loopStatusRequested'
        QtMocHelpers::SignalData<void(Mpris::LoopStatus)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Signal 'rateRequested'
        QtMocHelpers::SignalData<void(double)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 36 },
        }}),
        // Signal 'shuffleRequested'
        QtMocHelpers::SignalData<void(bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Signal 'volumeRequested'
        QtMocHelpers::SignalData<void(double)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 40 },
        }}),
        // Signal 'nextRequested'
        QtMocHelpers::SignalData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openUriRequested'
        QtMocHelpers::SignalData<void(const QUrl &)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 43, 44 },
        }}),
        // Signal 'pauseRequested'
        QtMocHelpers::SignalData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playRequested'
        QtMocHelpers::SignalData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playPauseRequested'
        QtMocHelpers::SignalData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previousRequested'
        QtMocHelpers::SignalData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seekRequested'
        QtMocHelpers::SignalData<void(qlonglong)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 50 },
        }}),
        // Signal 'seeked'
        QtMocHelpers::SignalData<void(qlonglong)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 52 },
        }}),
        // Signal 'setPositionRequested'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &, qlonglong)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 54, 55 }, { QMetaType::LongLong, 52 },
        }}),
        // Signal 'stopRequested'
        QtMocHelpers::SignalData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'serviceName'
        QtMocHelpers::SlotData<QString() const>(57, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setServiceName'
        QtMocHelpers::SlotData<void(const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 57 },
        }}),
        // Slot 'canQuit'
        QtMocHelpers::SlotData<bool() const>(59, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setCanQuit'
        QtMocHelpers::SlotData<void(bool)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 59 },
        }}),
        // Slot 'canRaise'
        QtMocHelpers::SlotData<bool() const>(61, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setCanRaise'
        QtMocHelpers::SlotData<void(bool)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 61 },
        }}),
        // Slot 'canSetFullscreen'
        QtMocHelpers::SlotData<bool() const>(63, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setCanSetFullscreen'
        QtMocHelpers::SlotData<void(bool)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 63 },
        }}),
        // Slot 'desktopEntry'
        QtMocHelpers::SlotData<QString() const>(65, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setDesktopEntry'
        QtMocHelpers::SlotData<void(const QString &)>(66, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 65 },
        }}),
        // Slot 'fullscreen'
        QtMocHelpers::SlotData<bool() const>(13, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setFullscreen'
        QtMocHelpers::SlotData<void(bool)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'hasTrackList'
        QtMocHelpers::SlotData<bool() const>(68, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setHasTrackList'
        QtMocHelpers::SlotData<void(bool)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 68 },
        }}),
        // Slot 'identity'
        QtMocHelpers::SlotData<QString() const>(70, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'setIdentity'
        QtMocHelpers::SlotData<void(const QString &)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 70 },
        }}),
        // Slot 'supportedUriSchemes'
        QtMocHelpers::SlotData<QStringList() const>(72, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'setSupportedUriSchemes'
        QtMocHelpers::SlotData<void(const QStringList &)>(73, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 72 },
        }}),
        // Slot 'supportedMimeTypes'
        QtMocHelpers::SlotData<QStringList() const>(74, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'setSupportedMimeTypes'
        QtMocHelpers::SlotData<void(const QStringList &)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 74 },
        }}),
        // Slot 'canControl'
        QtMocHelpers::SlotData<bool() const>(76, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setCanControl'
        QtMocHelpers::SlotData<void(bool)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 76 },
        }}),
        // Slot 'canShowInUI'
        QtMocHelpers::SlotData<bool() const>(78, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setCanShowInUI'
        QtMocHelpers::SlotData<void(bool)>(79, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 78 },
        }}),
        // Slot 'canGoNext'
        QtMocHelpers::SlotData<bool() const>(80, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setCanGoNext'
        QtMocHelpers::SlotData<void(bool)>(81, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 80 },
        }}),
        // Slot 'canGoPrevious'
        QtMocHelpers::SlotData<bool() const>(82, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setCanGoPrevious'
        QtMocHelpers::SlotData<void(bool)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 82 },
        }}),
        // Slot 'canPause'
        QtMocHelpers::SlotData<bool() const>(84, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setCanPause'
        QtMocHelpers::SlotData<void(bool)>(85, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 84 },
        }}),
        // Slot 'canPlay'
        QtMocHelpers::SlotData<bool() const>(86, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setCanPlay'
        QtMocHelpers::SlotData<void(bool)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 86 },
        }}),
        // Slot 'canSeek'
        QtMocHelpers::SlotData<bool() const>(88, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setCanSeek'
        QtMocHelpers::SlotData<void(bool)>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 88 },
        }}),
        // Slot 'loopStatus'
        QtMocHelpers::SlotData<Mpris::LoopStatus() const>(34, 2, QMC::AccessPublic, 0x80000000 | 33),
        // Slot 'setLoopStatus'
        QtMocHelpers::SlotData<void(Mpris::LoopStatus)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 },
        }}),
        // Slot 'maximumRate'
        QtMocHelpers::SlotData<double() const>(91, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'setMaximumRate'
        QtMocHelpers::SlotData<void(double)>(92, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 91 },
        }}),
        // Slot 'metadata'
        QtMocHelpers::SlotData<QVariantMap() const>(93, 2, QMC::AccessPublic, 0x80000000 | 94),
        // Slot 'setMetadata'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(95, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 94, 93 },
        }}),
        // Slot 'minimumRate'
        QtMocHelpers::SlotData<double() const>(96, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'setMinimumRate'
        QtMocHelpers::SlotData<void(double)>(97, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 96 },
        }}),
        // Slot 'playbackStatus'
        QtMocHelpers::SlotData<Mpris::PlaybackStatus() const>(98, 2, QMC::AccessPublic, 0x80000000 | 99),
        // Slot 'setPlaybackStatus'
        QtMocHelpers::SlotData<void(Mpris::PlaybackStatus)>(100, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 99, 98 },
        }}),
        // Slot 'position'
        QtMocHelpers::SlotData<qlonglong() const>(52, 2, QMC::AccessPublic, QMetaType::LongLong),
        // Slot 'setPosition'
        QtMocHelpers::SlotData<void(qlonglong)>(101, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 52 },
        }}),
        // Slot 'rate'
        QtMocHelpers::SlotData<double() const>(36, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'setRate'
        QtMocHelpers::SlotData<void(double)>(102, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 36 },
        }}),
        // Slot 'shuffle'
        QtMocHelpers::SlotData<bool() const>(38, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setShuffle'
        QtMocHelpers::SlotData<void(bool)>(103, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'volume'
        QtMocHelpers::SlotData<double() const>(40, 2, QMC::AccessPublic, QMetaType::Double),
        // Slot 'setVolume'
        QtMocHelpers::SlotData<void(double)>(104, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 40 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'serviceName'
        QtMocHelpers::PropertyData<QString>(57, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'canQuit'
        QtMocHelpers::PropertyData<bool>(59, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'canRaise'
        QtMocHelpers::PropertyData<bool>(61, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'canSetFullscreen'
        QtMocHelpers::PropertyData<bool>(63, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'desktopEntry'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'fullscreen'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'hasTrackList'
        QtMocHelpers::PropertyData<bool>(68, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'identity'
        QtMocHelpers::PropertyData<QString>(70, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'supportedUriSchemes'
        QtMocHelpers::PropertyData<QStringList>(72, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'supportedMimeTypes'
        QtMocHelpers::PropertyData<QStringList>(74, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'canControl'
        QtMocHelpers::PropertyData<bool>(76, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'canShowInUI'
        QtMocHelpers::PropertyData<bool>(78, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'canGoNext'
        QtMocHelpers::PropertyData<bool>(80, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'canGoPrevious'
        QtMocHelpers::PropertyData<bool>(82, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'canPause'
        QtMocHelpers::PropertyData<bool>(84, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'canPlay'
        QtMocHelpers::PropertyData<bool>(86, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'canSeek'
        QtMocHelpers::PropertyData<bool>(88, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'loopStatus'
        QtMocHelpers::PropertyData<Mpris::LoopStatus>(34, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 20),
        // property 'maximumRate'
        QtMocHelpers::PropertyData<double>(91, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'metadata'
        QtMocHelpers::PropertyData<QVariantMap>(93, 0x80000000 | 94, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 22),
        // property 'minimumRate'
        QtMocHelpers::PropertyData<double>(96, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'playbackStatus'
        QtMocHelpers::PropertyData<Mpris::PlaybackStatus>(98, 0x80000000 | 99, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 24),
        // property 'position'
        QtMocHelpers::PropertyData<qlonglong>(52, QMetaType::LongLong, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'rate'
        QtMocHelpers::PropertyData<double>(36, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'shuffle'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'volume'
        QtMocHelpers::PropertyData<double>(40, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MprisPlayer, qt_meta_tag_ZN11MprisPlayerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN11MprisPlayerE[] = {
    QMetaObject::SuperData::link<Mpris::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject MprisPlayer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MprisPlayerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MprisPlayerE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN11MprisPlayerE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MprisPlayerE_t>.metaTypes,
    nullptr
} };

void MprisPlayer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MprisPlayer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->serviceNameChanged(); break;
        case 1: _t->canQuitChanged(); break;
        case 2: _t->canRaiseChanged(); break;
        case 3: _t->canSetFullscreenChanged(); break;
        case 4: _t->desktopEntryChanged(); break;
        case 5: _t->fullscreenChanged(); break;
        case 6: _t->hasTrackListChanged(); break;
        case 7: _t->identityChanged(); break;
        case 8: _t->supportedUriSchemesChanged(); break;
        case 9: _t->supportedMimeTypesChanged(); break;
        case 10: _t->fullscreenRequested((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->quitRequested(); break;
        case 12: _t->raiseRequested(); break;
        case 13: _t->canControlChanged(); break;
        case 14: _t->canShowInUIChanged(); break;
        case 15: _t->canGoNextChanged(); break;
        case 16: _t->canGoPreviousChanged(); break;
        case 17: _t->canPauseChanged(); break;
        case 18: _t->canPlayChanged(); break;
        case 19: _t->canSeekChanged(); break;
        case 20: _t->loopStatusChanged(); break;
        case 21: _t->maximumRateChanged(); break;
        case 22: _t->metadataChanged(); break;
        case 23: _t->minimumRateChanged(); break;
        case 24: _t->playbackStatusChanged(); break;
        case 25: _t->positionChanged(); break;
        case 26: _t->rateChanged(); break;
        case 27: _t->shuffleChanged(); break;
        case 28: _t->volumeChanged(); break;
        case 29: _t->loopStatusRequested((*reinterpret_cast<std::add_pointer_t<Mpris::LoopStatus>>(_a[1]))); break;
        case 30: _t->rateRequested((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 31: _t->shuffleRequested((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->volumeRequested((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 33: _t->nextRequested(); break;
        case 34: _t->openUriRequested((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 35: _t->pauseRequested(); break;
        case 36: _t->playRequested(); break;
        case 37: _t->playPauseRequested(); break;
        case 38: _t->previousRequested(); break;
        case 39: _t->seekRequested((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 40: _t->seeked((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 41: _t->setPositionRequested((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2]))); break;
        case 42: _t->stopRequested(); break;
        case 43: { QString _r = _t->serviceName();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->setServiceName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 45: { bool _r = _t->canQuit();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 46: _t->setCanQuit((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: { bool _r = _t->canRaise();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 48: _t->setCanRaise((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 49: { bool _r = _t->canSetFullscreen();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 50: _t->setCanSetFullscreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 51: { QString _r = _t->desktopEntry();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 52: _t->setDesktopEntry((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 53: { bool _r = _t->fullscreen();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 54: _t->setFullscreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 55: { bool _r = _t->hasTrackList();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 56: _t->setHasTrackList((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 57: { QString _r = _t->identity();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 58: _t->setIdentity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 59: { QStringList _r = _t->supportedUriSchemes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 60: _t->setSupportedUriSchemes((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 61: { QStringList _r = _t->supportedMimeTypes();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 62: _t->setSupportedMimeTypes((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 63: { bool _r = _t->canControl();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 64: _t->setCanControl((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 65: { bool _r = _t->canShowInUI();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 66: _t->setCanShowInUI((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 67: { bool _r = _t->canGoNext();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 68: _t->setCanGoNext((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 69: { bool _r = _t->canGoPrevious();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 70: _t->setCanGoPrevious((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 71: { bool _r = _t->canPause();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 72: _t->setCanPause((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 73: { bool _r = _t->canPlay();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 74: _t->setCanPlay((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 75: { bool _r = _t->canSeek();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 76: _t->setCanSeek((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 77: { Mpris::LoopStatus _r = _t->loopStatus();
            if (_a[0]) *reinterpret_cast<Mpris::LoopStatus*>(_a[0]) = std::move(_r); }  break;
        case 78: _t->setLoopStatus((*reinterpret_cast<std::add_pointer_t<Mpris::LoopStatus>>(_a[1]))); break;
        case 79: { double _r = _t->maximumRate();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 80: _t->setMaximumRate((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 81: { QVariantMap _r = _t->metadata();
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 82: _t->setMetadata((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 83: { double _r = _t->minimumRate();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 84: _t->setMinimumRate((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 85: { Mpris::PlaybackStatus _r = _t->playbackStatus();
            if (_a[0]) *reinterpret_cast<Mpris::PlaybackStatus*>(_a[0]) = std::move(_r); }  break;
        case 86: _t->setPlaybackStatus((*reinterpret_cast<std::add_pointer_t<Mpris::PlaybackStatus>>(_a[1]))); break;
        case 87: { qlonglong _r = _t->position();
            if (_a[0]) *reinterpret_cast<qlonglong*>(_a[0]) = std::move(_r); }  break;
        case 88: _t->setPosition((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1]))); break;
        case 89: { double _r = _t->rate();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 90: _t->setRate((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 91: { bool _r = _t->shuffle();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 92: _t->setShuffle((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 93: { double _r = _t->volume();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 94: _t->setVolume((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::serviceNameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canQuitChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canRaiseChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canSetFullscreenChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::desktopEntryChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::fullscreenChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::hasTrackListChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::identityChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::supportedUriSchemesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::supportedMimeTypesChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)(bool )>(_a, &MprisPlayer::fullscreenRequested, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::quitRequested, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::raiseRequested, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canControlChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canShowInUIChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canGoNextChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canGoPreviousChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canPauseChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canPlayChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::canSeekChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::loopStatusChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::maximumRateChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::metadataChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::minimumRateChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::playbackStatusChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::positionChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::rateChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::shuffleChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::volumeChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)(Mpris::LoopStatus )>(_a, &MprisPlayer::loopStatusRequested, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)(double )>(_a, &MprisPlayer::rateRequested, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)(bool )>(_a, &MprisPlayer::shuffleRequested, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)(double )>(_a, &MprisPlayer::volumeRequested, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::nextRequested, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)(const QUrl & )>(_a, &MprisPlayer::openUriRequested, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::pauseRequested, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::playRequested, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::playPauseRequested, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::previousRequested, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)(qlonglong )>(_a, &MprisPlayer::seekRequested, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)(qlonglong )>(_a, &MprisPlayer::seeked, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)(const QDBusObjectPath & , qlonglong )>(_a, &MprisPlayer::setPositionRequested, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (MprisPlayer::*)()>(_a, &MprisPlayer::stopRequested, 42))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->serviceName(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->canQuit(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->canRaise(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->canSetFullscreen(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->desktopEntry(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->fullscreen(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->hasTrackList(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->identity(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->supportedUriSchemes(); break;
        case 9: *reinterpret_cast<QStringList*>(_v) = _t->supportedMimeTypes(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->canControl(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->canShowInUI(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->canGoNext(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->canGoPrevious(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->canPause(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->canPlay(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->canSeek(); break;
        case 17: *reinterpret_cast<Mpris::LoopStatus*>(_v) = _t->loopStatus(); break;
        case 18: *reinterpret_cast<double*>(_v) = _t->maximumRate(); break;
        case 19: *reinterpret_cast<QVariantMap*>(_v) = _t->metadata(); break;
        case 20: *reinterpret_cast<double*>(_v) = _t->minimumRate(); break;
        case 21: *reinterpret_cast<Mpris::PlaybackStatus*>(_v) = _t->playbackStatus(); break;
        case 22: *reinterpret_cast<qlonglong*>(_v) = _t->position(); break;
        case 23: *reinterpret_cast<double*>(_v) = _t->rate(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->shuffle(); break;
        case 25: *reinterpret_cast<double*>(_v) = _t->volume(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setServiceName(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setCanQuit(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setCanRaise(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setCanSetFullscreen(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setDesktopEntry(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setFullscreen(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setHasTrackList(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setIdentity(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setSupportedUriSchemes(*reinterpret_cast<QStringList*>(_v)); break;
        case 9: _t->setSupportedMimeTypes(*reinterpret_cast<QStringList*>(_v)); break;
        case 10: _t->setCanControl(*reinterpret_cast<bool*>(_v)); break;
        case 11: _t->setCanShowInUI(*reinterpret_cast<bool*>(_v)); break;
        case 12: _t->setCanGoNext(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setCanGoPrevious(*reinterpret_cast<bool*>(_v)); break;
        case 14: _t->setCanPause(*reinterpret_cast<bool*>(_v)); break;
        case 15: _t->setCanPlay(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setCanSeek(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setLoopStatus(*reinterpret_cast<Mpris::LoopStatus*>(_v)); break;
        case 18: _t->setMaximumRate(*reinterpret_cast<double*>(_v)); break;
        case 19: _t->setMetadata(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 20: _t->setMinimumRate(*reinterpret_cast<double*>(_v)); break;
        case 21: _t->setPlaybackStatus(*reinterpret_cast<Mpris::PlaybackStatus*>(_v)); break;
        case 22: _t->setPosition(*reinterpret_cast<qlonglong*>(_v)); break;
        case 23: _t->setRate(*reinterpret_cast<double*>(_v)); break;
        case 24: _t->setShuffle(*reinterpret_cast<bool*>(_v)); break;
        case 25: _t->setVolume(*reinterpret_cast<double*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MprisPlayer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MprisPlayer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MprisPlayerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int MprisPlayer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 95)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 95;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 95)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 95;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void MprisPlayer::serviceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MprisPlayer::canQuitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MprisPlayer::canRaiseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MprisPlayer::canSetFullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MprisPlayer::desktopEntryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MprisPlayer::fullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MprisPlayer::hasTrackListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MprisPlayer::identityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MprisPlayer::supportedUriSchemesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MprisPlayer::supportedMimeTypesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MprisPlayer::fullscreenRequested(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void MprisPlayer::quitRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void MprisPlayer::raiseRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void MprisPlayer::canControlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void MprisPlayer::canShowInUIChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void MprisPlayer::canGoNextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void MprisPlayer::canGoPreviousChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void MprisPlayer::canPauseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void MprisPlayer::canPlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void MprisPlayer::canSeekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void MprisPlayer::loopStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void MprisPlayer::maximumRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void MprisPlayer::metadataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void MprisPlayer::minimumRateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void MprisPlayer::playbackStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void MprisPlayer::positionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void MprisPlayer::rateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void MprisPlayer::shuffleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void MprisPlayer::volumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void MprisPlayer::loopStatusRequested(Mpris::LoopStatus _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void MprisPlayer::rateRequested(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 30, nullptr, _t1);
}

// SIGNAL 31
void MprisPlayer::shuffleRequested(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void MprisPlayer::volumeRequested(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 32, nullptr, _t1);
}

// SIGNAL 33
void MprisPlayer::nextRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void MprisPlayer::openUriRequested(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 34, nullptr, _t1);
}

// SIGNAL 35
void MprisPlayer::pauseRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void MprisPlayer::playRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void MprisPlayer::playPauseRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void MprisPlayer::previousRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void MprisPlayer::seekRequested(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 39, nullptr, _t1);
}

// SIGNAL 40
void MprisPlayer::seeked(qlonglong _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 40, nullptr, _t1);
}

// SIGNAL 41
void MprisPlayer::setPositionRequested(const QDBusObjectPath & _t1, qlonglong _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 41, nullptr, _t1, _t2);
}

// SIGNAL 42
void MprisPlayer::stopRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}
QT_WARNING_POP
